@@ -37,6 +37,8 @@ def lazy_cut(model, where):
 
     # Solve BIP under the worst-case scenario
     remain_time = obj.timelimit-model.cbGet(GRB.Callback.RUNTIME)
+    if remain_time <= 0:
+        return
     res = obj.solve_bip(c=c_wst, timelimit=remain_time)
 
     if obj.sense == GRB.MAXIMIZE and res['obj_bd'] > r_sol + EPSN:
@@ -221,10 +223,9 @@ class Model():
             # Log the iteration number
             ite_num += 1
             # If the model is infeasible, an exact solution is obtained.
-            if model.status == GRB.INFEASIBLE:
-                break
-            elif model.status != GRB.OPTIMAL and model.status != GRB.Status.TIME_LIMIT and model.status != GRB.SUBOPTIMAL and model.status != GRB.SOLUTION_LIMIT:
-                raise Exception("Unable to obtain feasible solution to the master problem (Gurobi status: {}, #ite: {})".format(model.status, ite_num))
+            if model.status == GRB.INFEASIBLE: break
+            # If no feasible solution found, terminate the approach
+            if model.solCount <= 0: break
             # Compute the regret of the current solution
             sol = {j: 1 if x[j].x > 0.5 else 0 for j in x}
             regret = self.evaluate(sol)
@@ -330,9 +331,11 @@ class Model():
         # Store results
         if model.status == GRB.Status.OPTIMAL or model.status == GRB.Status.TIME_LIMIT:
             self.lb = int(model.objBound + 1 - EPSN)
-            self.objval = int(model.objVal + EPSN)
+            # self.objval = int(model.objVal + EPSN)
             self.ttb = model._ttb
             self.sol = {j: 1 if x[j].x > 0.5 else 0 for j in x}
+            # Evaluate the obtained solution under its worst-case scenario
+            self.objval = self.evaluate(self.sol)
 
     def evaluate(self, sol: dict) -> int:
         """Calculate regret for a solution
